==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressControllerListBuilder extends io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.IngressControllerList,io.fabric8.openshift.api.model.operator.v1.IngressControllerListBuilder>{
  public IngressControllerListBuilder() {
    this(false);
  }
  public IngressControllerListBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressControllerList(), validationEnabled);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressControllerList(), validationEnabled);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerList instance) {
    this(fluent, instance, false);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerList instance) {
    this(instance,false);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerList build() {
    IngressControllerList buildable = new IngressControllerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerListBuilder that = (IngressControllerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerListBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class IngressControllerListBuilder extends io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.IngressControllerList,io.fabric8.openshift.api.model.operator.v1.IngressControllerListBuilder>{
  public IngressControllerListBuilder() {
    this(false);
  }
  public IngressControllerListBuilder(java.lang.Boolean validationEnabled) {
    this(new IngressControllerList(), validationEnabled);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent) {
    this(fluent, false);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new IngressControllerList(), validationEnabled);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerList instance) {
    this(fluent, instance, false);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.IngressControllerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerList instance) {
    this(instance,false);
  }
  public IngressControllerListBuilder(io.fabric8.openshift.api.model.operator.v1.IngressControllerList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.IngressControllerListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerList build() {
    IngressControllerList buildable = new IngressControllerList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IngressControllerListBuilder that = (IngressControllerListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
